summaryrefslogtreecommitdiffstats
path: root/src/zhuyin.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/zhuyin.h')
-rw-r--r--src/zhuyin.h16
1 files changed, 15 insertions, 1 deletions
diff --git a/src/zhuyin.h b/src/zhuyin.h
index 398b8d0..24128eb 100644
--- a/src/zhuyin.h
+++ b/src/zhuyin.h
@@ -619,7 +619,7 @@ bool zhuyin_get_zhuyin_key_rest_positions(zhuyin_instance_t * instance,
* @length: the length of the corresponding pinyin key.
* @returns: whether the get operation is successful.
*
* Get the length of the corresponding pinyin key.
*
*/
bool zhuyin_get_zhuyin_key_rest_length(zhuyin_instance_t * instance,
@@ -627,6 +627,20 @@ bool zhuyin_get_zhuyin_key_rest_length(zhuyin_instance_t * instance,
guint16 * length);
/**
+ * zhuyin_get_zhuyin_key_rest_offset:
+ * @instance: the zhuyin instance.
+ * @cursor: the cursor.
+ * @offset: the offset in the zhuyin array.
+ * @returns: whether the get operation is successful.
+ *
+ * Get the offset in the zhuyin key array.
+ *
+ */
+bool zhuyin_get_zhuyin_key_rest_offset(zhuyin_instance_t * instance,
+ guint16 cursor,
+ guint16 * offset);
+
+/**
* zhuyin_get_raw_full_pinyin:
* @instance: the zhuyin instance.
* @utf8_str: the modified raw full pinyin after choose candidate.
@@ -619,7 +619,7 @@ bool zhuyin_get_zhuyin_key_rest_positions(zhuyin_instance_t * instance,
* @returns: whether the get operation is successful.
*
- * Get the length of the corresponding pinyin key.
+ * Get the length of the corresponding zhuyin key.
*
*/